package com.yihu.hos.resource.service;

import com.yihu.hos.web.framework.model.Result;
import com.yihu.hos.resource.model.RsDemensionCategory;
import com.yihu.hos.resource.model.RsDimension;

import java.util.Map;

/**
 * Created by chenweida on 2016/1/26.
 */
public interface IRsDimensionService {
    Result getDimensionCategoryList() throws Exception;

    Result getDimensionList(Map<String, Object> conditionMap) throws Exception;

    RsDimension getDimensionById(String id) throws Exception;

    Result updateDimension(RsDimension rsDimension) throws Exception;

    Result addDimension(RsDimension rsDimension) throws Exception;

    Result deleteDimensionById(String id) throws Exception;

    Result getDimensionCatecoryList(Map<String, Object> conditionMap) throws Exception;

    Result deleteDimensionCatetory(String id) throws Exception;

    RsDemensionCategory getDimensionCatetoryById(String id) throws Exception;

    Result addDimensionCatetroy(RsDemensionCategory r)throws Exception;

    Result updateDimensionCatetroy(RsDemensionCategory r)throws Exception;


    ;
}
